@@ -22,30 +22,30 @@
 Creates an ad through a utility function.
 """
 
-from facebookads import FacebookSession
 from facebookads import FacebookAdsApi
-from facebookads.objects import (
-    AdAccount,
-    AdPreview,
-    AdSet,
-)
+from facebookads import FacebookSession
+from facebookads.adobjects.business import Business
+from facebookads.adobjects.adaccount import AdAccount
+from facebookads.adobjects.adpreview import AdPreview
+from facebookads.adobjects.adset import AdSet
+from facebookads.adobjects.adpromotedobject import AdPromotedObject
 
 import ad_creation_utils
-import configparser
+import json
 import os
 
-config = configparser.RawConfigParser()
 this_dir = os.path.dirname(__file__)
-config_filename = os.path.join(this_dir, 'my_app_session.cfg')
+config_filename = os.path.join(this_dir, 'config.json')
 
-with open(config_filename) as config_file:
-    config.readfp(config_file)
+config_file = open(config_filename)
+config = json.load(config_file)
+config_file.close()
 
 ### Setup session and api objects
 session = FacebookSession(
-    config.get('Authentication', 'app_id'),
-    config.get('Authentication', 'app_secret'),
-    config.get('Authentication', 'access_token'),
+    config['app_id'],
+    config['app_secret'],
+    config['access_token'],
 )
 api = FacebookAdsApi(session)
 
@@ -54,13 +54,13 @@ if __name__ == '__main__':
 
     # Get my account (first account associated with the user associated with the
     #                 session of the default api)
-    my_account = AdAccount.get_my_account()
+    my_account = AdAccount(fbid=config['act_id'])
 
     print('**** Creating ad...')
 
     # Create my ad
     my_ad = ad_creation_utils.create_website_clicks_ad(
-        account=my_account,
+        account=config['act_id'],
 
         name="Visit Seattle",
         country='US',
@@ -68,28 +68,37 @@ if __name__ == '__main__':
         title="Visit Seattle",                             # How it looks
         body="Beautiful Puget Sound.",
         url="http://www.seattle.gov/visiting/",
-        image_path=os.path.join(this_dir, 'test.png'),
+        image_path=os.path.join(
+            os.path.dirname(__file__),
+            os.pardir,
+            'facebookads/test/misc/image.png'
+        ),
 
-        bid_type=AdSet.BidType.cpm,
-        bid_info={AdSet.Field.BidInfo.impressions: 53},  # $0.53 / thousand
+        optimization_goal=AdSet.OptimizationGoal.offsite_conversions,
+        pixel_id=config['pixel_id'],
+        billing_event=AdSet.BillingEvent.impressions,
+        bid_amount=53,  # $0.53 / thousand
         daily_budget=1000,  # $10.00 per day
 
         age_min=13,
         age_max=65,
 
-        paused=True,  # Default is False but let's keep this test ad paused
+        campaign=config['campaign_id'],
+        status=AdSet.Status.paused,
+        # Default is False but let's keep this test ad paused
     )
     print('**** Done!')
 
     # Get the preview and write an html file
-    preview = my_ad.get_ad_preview(params={
-        AdPreview.Field.ad_format: AdPreview.AdFormat.right_column_standard
+    preview = my_ad.get_previews(params={
+        'ad_format': AdPreview.AdFormat.right_column_standard,
     })
     preview_filename = os.path.join(this_dir, 'preview_ad.html')
     preview_file = open(preview_filename, 'w')
     preview_file.write(
         "<html><head><title>Facebook Ad Preview</title><body>%s</body></html>"
-        % preview.get_html()
     )
+    for each_ad in preview:
+        preview_file.write(each_ad.get_html())
     preview_file.close()
     print('**** %s has been created!' % preview_filename)
