@@ -34,17 +34,21 @@ import json
 from .. import objects
 from .. import specs
 from .. import api
+from .. import apiconfig
 from .. import session
 from .. import exceptions as fbexceptions
 
-
 class FacebookAdsTestCase(unittest.TestCase):
 
     TEST_SESSION = None
     TEST_API = None
+    TEST_BUSINESS = None
     TEST_ACCOUNT = None
     TEST_ID = str(int(time.time()) % 1000)
-    TEST_IMAGE_PATH = os.path.join(os.path.dirname(__file__), 'test.png')
+    TEST_IMAGE_PATH = os.path.join(os.path.dirname(__file__), 'misc/image.png')
+    TEST_ZIP_PATH = os.path.join(os.path.dirname(__file__), 'misc/images.zip')
+    TEST_SECONDARY_ACCOUNT = None
+    TEST_SECONDARY_BUSINESS = None
 
     def setUp(self):
         super(FacebookAdsTestCase, self).setUp()
@@ -92,19 +96,19 @@ class FacebookAdsTestCase(unittest.TestCase):
 
         return creative
 
-    def new_test_ad_campaign(self):
-        campaign = objects.AdCampaign(
+    def new_test_campaign(self):
+        campaign = objects.Campaign(
             parent_id=self.TEST_ACCOUNT.get_id_assured(),
         )
         self.delete_in_teardown(campaign)
         campaign.update({
-            objects.AdCampaign.Field.name: 'AdSetTestCase %s' % self.TEST_ID,
+            objects.Campaign.Field.name: 'CampaignTestCase %s' % self.TEST_ID,
         })
 
         return campaign
 
     def new_test_ad_set(self, campaign):
-        campaign_group_id = campaign.get_id_assured()
+        campaign_id = campaign.get_id_assured()
 
         ad_set = objects.AdSet(
             parent_id=self.TEST_ACCOUNT.get_id_assured(),
@@ -112,16 +116,17 @@ class FacebookAdsTestCase(unittest.TestCase):
         self.delete_in_teardown(ad_set)
         ad_set.update({
             objects.AdSet.Field.name: 'AdSetTestCase %s' % self.TEST_ID,
-            objects.AdSet.Field.campaign_group_id: campaign_group_id,
-            objects.AdSet.Field.status: objects.AdSet.Status.paused,
+            objects.AdSet.Field.campaign_id: campaign_id,
+            'status': objects.AdSet.Status.paused,
             objects.AdSet.Field.pacing_type: [
                 objects.AdSet.PacingType.standard,
             ],
-            objects.AdSet.Field.daily_budget: 100,
-            objects.AdSet.Field.bid_type: objects.AdSet.BidType.cpc,
-            objects.AdSet.Field.bid_info: {
-                objects.AdSet.Field.BidInfo.clicks: 20,
-            },
+            objects.AdSet.Field.daily_budget: 2500,
+            objects.AdSet.Field.optimization_goal:
+            objects.AdSet.OptimizationGoal.impressions,
+            objects.AdSet.Field.billing_event:
+            objects.AdSet.BillingEvent.impressions,
+            objects.AdSet.Field.bid_amount: 500,
             objects.AdSet.Field.targeting: {
                 objects.TargetingSpecsField.geo_locations: {
                     'countries': [
@@ -133,8 +138,8 @@ class FacebookAdsTestCase(unittest.TestCase):
 
         return ad_set
 
-    def new_test_ad_group(self, ad_set):
-        campaign_id = ad_set.get_id_assured()
+    def new_test_ad(self, ad_set):
+        adset_id = ad_set.get_id_assured()
 
         img = objects.AdImage(
             parent_id=self.TEST_ACCOUNT.get_id_assured(),
@@ -149,7 +154,8 @@ class FacebookAdsTestCase(unittest.TestCase):
         )
         self.delete_in_teardown(creative)
         creative.update({
-            objects.AdCreative.Field.title: "Test AdCreative %s" % self.TEST_ID,
+            objects.AdCreative.Field.title:
+                "Test AdCreative %s" % self.TEST_ID,
             objects.AdCreative.Field.body: "Test ad",
             objects.AdCreative.Field.object_url: "https://www.facebook.com/",
             objects.AdCreative.Field.image_hash: image_hash,
@@ -157,20 +163,20 @@ class FacebookAdsTestCase(unittest.TestCase):
         creative.remote_create()
         creative_id = creative.get_id_assured()
 
-        ad_group = objects.AdGroup(
+        ad = objects.Ad(
             parent_id=self.TEST_ACCOUNT.get_id_assured(),
         )
-        self.delete_in_teardown(ad_group)
-        ad_group.update({
-            objects.AdGroup.Field.name: 'AdGroupTestCase %s' % self.TEST_ID,
-            objects.AdGroup.Field.campaign_id: campaign_id,
-            objects.AdGroup.Field.creative: {
-                objects.AdGroup.Field.Creative.creative_id: creative_id,
+        self.delete_in_teardown(ad)
+        ad.update({
+            objects.Ad.Field.name: 'AdTestCase %s' % self.TEST_ID,
+            objects.Ad.Field.adset_id: adset_id,
+            objects.Ad.Field.creative: {
+                'creative_id': creative_id,
             },
-            objects.AdGroup.Field.status: objects.AdGroup.Status.paused,
+            'status': objects.Ad.Status.paused,
         })
 
-        return ad_group
+        return ad
 
     def new_test_ad_image(self):
         img = objects.AdImage(
@@ -181,6 +187,29 @@ class FacebookAdsTestCase(unittest.TestCase):
         img.remote_create()
         return img
 
+    def new_test_ad_label(self):
+        label = objects.AdLabel(
+            parent_id=self.TEST_ACCOUNT.get_id_assured(),
+        )
+        label[objects.AdLabel.Field.name] = 'Test Label'
+        label.remote_create()
+        self.delete_in_teardown(label)
+        return label
+
+    def new_test_pixel(self):
+        account = objects.AdAccount(self.TEST_ACCOUNT.get_id_assured())
+        pixels = account.get_ads_pixels()
+
+        if len(pixels) > 0:
+            return pixels[0]
+
+        pixel = objects.AdsPixel(
+            parent_id=self.TEST_ACCOUNT.get_id_assured(),
+        )
+        pixel[objects.AdsPixel.Field.name] = 'My new Pixel'
+        pixel.remote_create()
+        return pixel
+
 
 class AbstractObjectTestCase(FacebookAdsTestCase):
     pass
@@ -267,15 +296,58 @@ class AbstractCrudObjectTestCase(AbstractObjectTestCase):
         assert 'execution_options' not in subject
         assert cached_data == subject._data
 
+    @classmethod
+    def assert_can_save(cls, subject):
+        """
+        Asserts that the id is empty before creation and then updates
+        """
+        assert subject[subject.Field.id] is None
+
+        subject.remote_save()
+
+        assert subject[subject.Field.id] is not None
+
+        subject.remote_save()
+
+        mirror = cls.get_mirror(subject)
+
+        assert subject[subject.Field.id] == mirror[mirror.Field.id]
+
+    def test_can_select_api_version(self):
+        image_file = os.path.join(os.path.dirname(__file__), 'test.png')
+
+        test_image_one = objects.AdImage(
+            parent_id=self.TEST_ACCOUNT.get_id_assured(),
+        )
+
+        test_image_one[objects.AdImage.Field.filename] = image_file
+
+        assert test_image_one.remote_create(
+            api_version=apiconfig.ads_api_config['API_VERSION']) is not None
+
+        test_image_two = objects.AdImage(
+            parent_id=self.TEST_ACCOUNT.get_id_assured(),
+        )
+
+        test_image_two[objects.AdImage.Field.filename] = image_file
+
+        try:
+            test_image_two.remote_create(
+                api_version=apiconfig.ads_api_config['API_VERSION'])
+        except fbexceptions.FacebookBadObjectError as e:
+            assert e is not None
+
 
 class AdUserTestCase(AbstractCrudObjectTestCase):
 
     def setUp(self):
         super(AdUserTestCase, self).setUp()
         self.orig_aduser_fields = objects.AdUser.get_default_read_fields()
-        objects.AdUser.set_default_read_fields([
-            objects.AdUser.Field.name,
-        ])
+        objects.AdUser.set_default_read_fields(
+            [
+                objects.AdUser.Field.name,
+            ],
+        )
 
     def tearDown(self):
         objects.AdUser.set_default_read_fields(self.orig_aduser_fields)
@@ -287,7 +359,7 @@ class AdUserTestCase(AbstractCrudObjectTestCase):
         self.assert_can_read(self.subject)
 
         for user in self.TEST_ACCOUNT.get_ad_users(
-            fields=[objects.AdUser.Field.role]
+            fields=[objects.AdUser.Field.role],
         ):
             if user == self.subject:
                 valid_roles = (
@@ -301,13 +373,15 @@ class AdAccountTestCase(AbstractCrudObjectTestCase):
 
     def setUp(self):
         super(AdAccountTestCase, self).setUp()
-        self.orig_adaccount_fields = objects.AdAccount.get_default_read_fields()
-        objects.AdAccount.set_default_read_fields([
-            objects.AdAccount.Field.account_status,
-            objects.AdAccount.Field.business_name,
-            objects.AdAccount.Field.timezone_name,
-            objects.AdAccount.Field.daily_spend_limit,
-        ])
+        self.orig_adaccount_fields = \
+            objects.AdAccount.get_default_read_fields()
+        objects.AdAccount.set_default_read_fields(
+            [
+                objects.AdAccount.Field.account_status,
+                objects.AdAccount.Field.business_name,
+                objects.AdAccount.Field.timezone_name,
+            ],
+        )
 
     def tearDown(self):
         objects.AdAccount.set_default_read_fields(self.orig_adaccount_fields)
@@ -318,22 +392,24 @@ class AdAccountTestCase(AbstractCrudObjectTestCase):
         self.assert_can_read(self.subject)
 
 
-class AdCampaignTestCase(AbstractCrudObjectTestCase):
+class CampaignTestCase(AbstractCrudObjectTestCase):
 
     def setUp(self):
-        super(AdCampaignTestCase, self).setUp()
-        self.orig_adcampaign_fields = \
-            objects.AdCampaign.get_default_read_fields()
-        objects.AdCampaign.set_default_read_fields([
-            objects.AdCampaign.Field.name,
-        ])
+        super(CampaignTestCase, self).setUp()
+        self.orig_campaign_fields = \
+            objects.Campaign.get_default_read_fields()
+        objects.Campaign.set_default_read_fields(
+            [
+                objects.Campaign.Field.name,
+            ],
+        )
 
     def tearDown(self):
-        objects.AdCampaign.set_default_read_fields(self.orig_adcampaign_fields)
-        super(AdCampaignTestCase, self).tearDown()
+        objects.Campaign.set_default_read_fields(self.orig_campaign_fields)
+        super(CampaignTestCase, self).tearDown()
 
     def runTest(self):
-        self.subject = self.new_test_ad_campaign()
+        self.subject = self.new_test_campaign()
 
         self.assert_can_validate(self.subject)
 
@@ -342,8 +418,8 @@ class AdCampaignTestCase(AbstractCrudObjectTestCase):
         self.assert_can_read(self.subject)
 
         self.subject.update({
-            objects.AdCampaign.Field.name: 'AdCampaignTestCase Updated %s'
-                                           % self.TEST_ID
+            objects.Campaign.Field.name:
+                'CampaignTestCase Updated %s' % self.TEST_ID,
         })
         self.assert_can_update(self.subject)
 
@@ -355,16 +431,16 @@ class AdCampaignTestCase(AbstractCrudObjectTestCase):
 class GetByIDsTestCase(AbstractCrudObjectTestCase):
 
     def runTest(self):
-        self.campaign1 = self.new_test_ad_campaign()
+        self.campaign1 = self.new_test_campaign()
         self.campaign1['name'] = "Campaign 1"
         self.campaign1.remote_create()
-        self.campaign2 = self.new_test_ad_campaign()
+        self.campaign2 = self.new_test_campaign()
         self.campaign2['name'] = "Campaign 2"
         self.campaign2.remote_create()
 
-        campaigns = objects.AdCampaign.get_by_ids(
+        campaigns = objects.Campaign.get_by_ids(
             ids=[self.campaign1.get_id(), self.campaign2.get_id()],
-            fields=['name']
+            fields=['name'],
         )
 
         assert len(campaigns) == 2
@@ -376,31 +452,33 @@ class DefaultReadFieldsTestCase(AbstractCrudObjectTestCase):
 
     def setUp(self):
         super(DefaultReadFieldsTestCase, self).setUp()
-        self.orig_adcampaign_fields = \
-            objects.AdCampaign.get_default_read_fields()
+        self.orig_campaign_fields = \
+            objects.Campaign.get_default_read_fields()
 
     def tearDown(self):
-        objects.AdCampaign.set_default_read_fields(self.orig_adcampaign_fields)
+        objects.Campaign.set_default_read_fields(self.orig_campaign_fields)
         super(DefaultReadFieldsTestCase, self).tearDown()
 
     def runTest(self):
-        campaign = self.new_test_ad_campaign()
+        campaign = self.new_test_campaign()
         campaign.remote_create()
-        same_campaign = objects.AdCampaign(campaign.get_id())
+        same_campaign = objects.Campaign(campaign.get_id())
         same_campaign.remote_read()
-        assert objects.AdCampaign.Field.status not in same_campaign
+        assert objects.Campaign.Field.status not in same_campaign
 
-        campaigns = objects.AdCampaign.get_by_ids(ids=[campaign.get_id()])
-        assert objects.AdCampaign.Field.status not in campaigns[0]
+        campaigns = objects.Campaign.get_by_ids(ids=[campaign.get_id()])
+        assert objects.Campaign.Field.status not in campaigns[0]
 
-        objects.AdCampaign.set_default_read_fields([
-            objects.AdCampaign.Field.status,
-        ])
+        objects.Campaign.set_default_read_fields(
+            [
+                objects.Campaign.Field.status,
+            ],
+        )
         same_campaign.remote_read()
-        assert objects.AdCampaign.Field.status in same_campaign
+        assert objects.Campaign.Field.status in same_campaign
 
-        campaigns = objects.AdCampaign.get_by_ids(ids=[campaign.get_id()])
-        assert objects.AdCampaign.Field.status in campaigns[0]
+        campaigns = objects.Campaign.get_by_ids(ids=[campaign.get_id()])
+        assert objects.Campaign.Field.status in campaigns[0]
 
 
 class AdSetTestCase(AbstractCrudObjectTestCase):
@@ -408,20 +486,21 @@ class AdSetTestCase(AbstractCrudObjectTestCase):
     def setUp(self):
         super(AdSetTestCase, self).setUp()
         self.orig_adset_fields = objects.AdSet.get_default_read_fields()
-        objects.AdSet.set_default_read_fields([
-            objects.AdSet.Field.daily_budget,
-            objects.AdSet.Field.created_time,
-            objects.AdSet.Field.campaign_group_id,
-            objects.AdSet.Field.bid_type,
-            objects.AdSet.Field.name,
-        ])
+        objects.AdSet.set_default_read_fields(
+            [
+                objects.AdSet.Field.daily_budget,
+                objects.AdSet.Field.created_time,
+                objects.AdSet.Field.campaign_id,
+                objects.AdSet.Field.name,
+            ],
+        )
 
     def tearDown(self):
         objects.AdSet.set_default_read_fields(self.orig_adset_fields)
         super(AdSetTestCase, self).tearDown()
 
     def runTest(self):
-        self.campaign = self.new_test_ad_campaign()
+        self.campaign = self.new_test_campaign()
         self.campaign.remote_create()
 
         self.subject = self.new_test_ad_set(self.campaign)
@@ -433,7 +512,8 @@ class AdSetTestCase(AbstractCrudObjectTestCase):
         self.assert_can_read(self.subject)
 
         self.subject.update({
-            objects.AdSet.Field.name: 'AdSetTestCase Updated %s' % self.TEST_ID,
+            objects.AdSet.Field.name:
+                'AdSetTestCase Updated %s' % self.TEST_ID,
         })
         self.assert_can_update(self.subject)
 
@@ -442,36 +522,38 @@ class AdSetTestCase(AbstractCrudObjectTestCase):
         self.assert_can_delete(self.subject)
 
 
-class AdGroupTestCase(AbstractCrudObjectTestCase):
+class AdTestCase(AbstractCrudObjectTestCase):
 
     def setUp(self):
-        super(AdGroupTestCase, self).setUp()
-        self.orig_adgroup_fields = objects.AdGroup.get_default_read_fields()
-        objects.AdGroup.set_default_read_fields([
-            objects.AdGroup.Field.created_time,
-            objects.AdGroup.Field.name,
-            objects.AdGroup.Field.campaign_id,
-        ])
+        super(AdTestCase, self).setUp()
+        self.orig_ad_fields = objects.Ad.get_default_read_fields()
+        objects.Ad.set_default_read_fields(
+            [
+                objects.Ad.Field.created_time,
+                objects.Ad.Field.name,
+                objects.Ad.Field.adset_id,
+            ],
+        )
 
     def tearDown(self):
-        objects.AdGroup.set_default_read_fields(self.orig_adgroup_fields)
-        super(AdGroupTestCase, self).tearDown()
+        objects.Ad.set_default_read_fields(self.orig_ad_fields)
+        super(AdTestCase, self).tearDown()
 
     def runTest(self):
-        self.campaign = self.new_test_ad_campaign()
+        self.campaign = self.new_test_campaign()
         self.campaign.remote_create()
 
         self.ad_set = self.new_test_ad_set(self.campaign)
         self.ad_set.remote_create()
 
-        self.subject = self.new_test_ad_group(self.ad_set)
+        self.subject = self.new_test_ad(self.ad_set)
 
         self.assert_can_create(self.subject)
 
         self.assert_can_read(self.subject)
 
         self.subject.update({
-            objects.AdGroup.Field.name: 'AdGroupTestCase Updated %s' % (
+            objects.Ad.Field.name: 'AdTestCase Updated %s' % (
                 self.TEST_ID
             ),
         })
@@ -482,6 +564,17 @@ class AdGroupTestCase(AbstractCrudObjectTestCase):
         self.assert_can_delete(self.subject)
 
 
+class TargetingSearchTestCase(AbstractObjectTestCase):
+    def test_call(self):
+        params = {
+            'q': 'uk',
+            'type': 'adgeolocation',
+            'location_types': ['country'],
+        }
+        resp = objects.TargetingSearch.search(params=params)
+        assert len(resp) > 0
+
+
 class CustomAudienceTestCase(AbstractCrudObjectTestCase):
 
     def runTest(self):
@@ -491,6 +584,7 @@ class CustomAudienceTestCase(AbstractCrudObjectTestCase):
         self.delete_in_teardown(ca)
         ca[objects.CustomAudience.Field.name] = \
             'Custom Audience Test ' + self.TEST_ID
+        ca[objects.CustomAudience.Field.subtype] = 'CUSTOM'
         ca.remote_create()
 
         users = ['someone@example.com']
@@ -558,31 +652,130 @@ class MultiProductAdObjectStorySpecTestCase(AbstractCrudObjectTestCase):
         self.assert_can_delete(creative)
 
 
-class BlameFieldSpecsTestCase(AbstractCrudObjectTestCase):
-    def runTest(self):
-        set = objects.AdSet(
-            parent_id=self.TEST_ACCOUNT.get_id_assured(),
-        )
-        self.delete_in_teardown(set)
-        set['name'] = 'foo'
-        set['daily_budget'] = 100
-        set['campaign_status'] = 100
-
-        try:
-            set.remote_create()
-        except fbexceptions.FacebookRequestError as e:
-            assert e.api_blame_field_specs() == [['campaign_group_id']]
-        else:
-            self.fail("remote_create unexpectedly succeeded")
-
-
 class AdImageTestCase(AbstractCrudObjectTestCase):
 
+    def test_can_upload_zip(self):
+        images = objects.AdImage.remote_create_from_zip(
+            filename=self.TEST_ZIP_PATH,
+            parent_id=self.TEST_ACCOUNT.get_id(),
+        )
+        assert len(images) == 2
+
     def test_can_read(self):
         self.new_test_ad_image()
         self.TEST_ACCOUNT.get_ad_images()
 
 
+class InsightsTestCase(AbstractCrudObjectTestCase):
+    def test_can_read_without_job(self):
+        self.TEST_ACCOUNT.get_insights(
+            fields=[
+                objects.Insights.Field.unique_clicks,
+                objects.Insights.Field.impressions,
+                objects.Insights.Field.campaign_id,
+                objects.Insights.Field.campaign_name,
+            ],
+            params={
+                'date_preset': objects.Insights.Preset.today,
+                'level': objects.Insights.Level.campaign,
+            },
+        )
+
+
+class AdLabelTestCase(AbstractCrudObjectTestCase):
+    """
+        Create a new ad set object and test adding and removing labels
+    """
+    def runTest(self):
+        label = self.new_test_ad_label()
+        adlabels = [label.get_id()]
+        ad_set = self.new_test_ad_set()
+
+        try:
+            ad_set.add_labels(adlabels)
+        except:
+            self.fail("Could not add ad labels")
+
+        try:
+            ad_set.remove_labels(adlabels)
+        except:
+            self.fail("Could not remove ad labels")
+
+
+class AdsPixelTestCase(AbstractCrudObjectTestCase):
+
+    def runTest(self):
+        pixel = self.new_test_pixel()
+
+        pixel.share_pixel(
+            self.TEST_BUSINESS.get_id(),
+            self.TEST_SECONDARY_ACCOUNT.get_id(),
+        )
+
+        pixel.unshare_pixel_from_ad_account(
+            self.TEST_BUSINESS.get_id(),
+            self.TEST_SECONDARY_ACCOUNT.get_id(),
+        )
+
+        pixel.share_pixel_with_ad_account(
+            self.TEST_BUSINESS.get_id(),
+            self.TEST_SECONDARY_ACCOUNT.get_id(),
+        )
+
+        old_resp = pixel.list_ad_accounts(
+            self.TEST_BUSINESS.get_id(),
+        )
+
+        resp = pixel.get_ad_accounts(
+            self.TEST_BUSINESS.get_id(),
+        )
+
+        assert len(old_resp) > 1
+        assert len(resp) > 1
+
+        pixel.share_pixel_agencies(
+            self.TEST_BUSINESS.get_id(),
+            self.TEST_SECONDARY_BUSINESS.get_id(),
+        )
+
+        pixel.unshare_pixel_from_agency(
+            self.TEST_BUSINESS.get_id(),
+            self.TEST_SECONDARY_BUSINESS.get_id(),
+        )
+
+        pixel.share_pixel_with_agency(
+            self.TEST_BUSINESS.get_id(),
+            self.TEST_SECONDARY_BUSINESS.get_id(),
+        )
+
+        old_resp = pixel.list_shared_agencies()
+        resp = pixel.get_agencies()
+
+        assert len(old_resp) > 1
+        assert len(resp) > 1
+
+
+class CustomConversion(AbstractCrudObjectTestCase):
+
+    @unittest.skip('Deletion is not supported')
+    def runTest(self):
+        pixel = self.new_test_pixel()
+        custom_conversion = objects.CustomConversion(
+            parent_id=self.TEST_ACCOUNT.get_id_assured(),
+        )
+        custom_conversion.update({
+            objects.CustomConversion.Field.name: 'Example Custom Conversion',
+            objects.CustomConversion.Field.pixel_id:
+            pixel[objects.AdsPixel.id],
+            objects.CustomConversion.Field.pixel_rule: {
+                'url': {'i_contains': 'thankyou.html'},
+            },
+            objects.CustomConversion.Field.custom_event_type: 'PURCHASE',
+        })
+
+        custom_conversion.remote_create()
+
+
 class BatchTestCase(FacebookAdsTestCase):
 
     def setUp(self):
@@ -593,15 +786,20 @@ class BatchTestCase(FacebookAdsTestCase):
     def create_campaigns(self):
         ret_val = []
         for i in range(self.num_campaigns):
-            campaign = self.new_test_ad_campaign()
+            campaign = self.new_test_campaign()
             ret_val.append(campaign)
             self.delete_in_teardown(campaign)
         return ret_val
 
     def check_ids(self, campaigns):
         # Check if the campaigns were created by counting distinct ids
-        ids = set(filter(None, [campaign[objects.AdCampaign.Field.id]
-                                for campaign in campaigns]))
+        ids = set(
+            filter(
+                None,
+                [campaign[objects.Campaign.Field.id]
+                    for campaign in campaigns],
+            ),
+        )
         self.created_ids.append(ids)
         self.assertEqual(len(ids), len(campaigns))
 
@@ -638,9 +836,12 @@ if __name__ == '__main__':
     config_file.close()
 
     test_account_id = config['act_id']
+    test_business_id = config['business']
     page_id = config['page_id']
     app_id = config['app_id']
     app_secret = config['app_secret']
+    test_sec_business_id = config['sec_business']
+    test_sec_account_id = config['sec_act_id']
 
     if 'access_token' in config:
         access_token = config['access_token']
@@ -653,10 +854,10 @@ if __name__ == '__main__':
     FacebookAdsTestCase.TEST_SESSION = session.FacebookSession(
         app_id,
         app_secret,
-        access_token
+        access_token,
     )
     FacebookAdsTestCase.TEST_API = api.FacebookAdsApi(
-        FacebookAdsTestCase.TEST_SESSION
+        FacebookAdsTestCase.TEST_SESSION,
     )
     api.FacebookAdsApi.set_default_api(FacebookAdsTestCase.TEST_API)
 
@@ -664,5 +865,8 @@ if __name__ == '__main__':
         test_account_id = 'act_' + test_account_id
     FacebookAdsTestCase.TEST_ACCOUNT = objects.AdAccount(test_account_id)
     FacebookAdsTestCase.PAGE_ID = page_id
+    FacebookAdsTestCase.TEST_BUSINESS = test_business_id
+    FacebookAdsTestCase.TEST_SECONDARY_ACCOUNT = test_sec_account_id
+    FacebookAdsTestCase.TEST_SECONDARY_BUSINESS = test_sec_business_id
 
     unittest.main()
